Learn R Programming

nycOpenData (version 0.1.6)

nyc_homeless_population_by_year: NYC Homeless Population By Year

Description

Directory Of Homeless Population By Year

Usage

nyc_homeless_population_by_year(
  limit = 10000,
  filters = list(),
  timeout_sec = 30
)

Value

A tibble containing Directory Of Homeless Population By Year data.

Arguments

limit

Number of rows to retrieve (default = 10,000).

filters

Optional list of field-value pairs to filter results.

timeout_sec

Request timeout in seconds (default = 30).

Details

Table of homeless population by Year (for years 2009 through 2012)

Examples

Run this code
# Examples that hit the live NYC Open Data API are guarded so CRAN checks
# do not fail when the network is unavailable or slow.
if (interactive() && curl::has_internet()) {
  # Quick example (fetch 2 rows)
  small_sample <- nyc_homeless_population_by_year(limit = 2)
  small_sample

  nyc_homeless_population_by_year(limit = 2, filters = list(area = "Subways"))
}

Run the code above in your browser using DataLab