Learn R Programming

nycOpenData (version 0.1.6)

nyc_pets_in_shelters: NYC Pets in Shelter Report

Description

Local Law 97 of 2021 - Pets in Shelter Report from NYC Open Data.

Usage

nyc_pets_in_shelters(limit = 10000, filters = list(), timeout_sec = 30)

Value

A tibble containing Local Law 97 of 2021 - Pets in Shelter Report data.

Arguments

limit

Number of rows to retrieve (default = 10,000).

filters

Optional list of field-value pairs to filter results.

timeout_sec

Request timeout in seconds (default = 30).

Details

This quarterly report provides survey response data about the types of pets whose owners enter homeless shelters. Data is aggregated at the quarterly level (ie: 2024 Q3). The unit of analysis is a fiscal year quarter: Quarter 1 (Q1): July - September; Quarter 2 (Q2): October - December; Quarter 3 (Q3): January - March; Quarter 4 (Q4): April - June.

Examples

Run this code
# Examples that hit the live NYC Open Data API are guarded so CRAN checks
# do not fail when the network is unavailable or slow.
if (interactive() && curl::has_internet()) {
  # Quick example (fetch 2 rows)
  small_sample <- nyc_pets_in_shelters(limit = 2)
  small_sample

  nyc_pets_in_shelters(limit = 2, filters = list(date_quarter = "Qtr 1"))
}

Run the code above in your browser using DataLab