Retrieves the current NYC Open Data catalog and returns datasets available for use with `nyc_pull_dataset()`.
Examples
if (interactive() && curl::has_internet()) {
nyc_list_datasets()
}
Retrieves the current NYC Open Data catalog and returns datasets available for use with `nyc_pull_dataset()`.
if (interactive() && curl::has_internet()) {
nyc_list_datasets()
}