View source: R/nyc_ll97_shelter_pets.R
| nyc_locallaw97_shelter_pets | R Documentation |
Downloads Local Law 97 of 2021 - Pets in Shelter Report data from NYC Open Data.
nyc_locallaw97_shelter_pets(limit = 10000, filters = list(), timeout_sec = 30)
limit |
Number of rows to retrieve (default = 10,000). |
filters |
Optional list of field-value pairs to filter results. |
timeout_sec |
Request timeout in seconds (default = 30). |
This dataset contains quarterly survey response data on the types of pets whose owners entered New York City homeless shelters. Each row represents combined survey responses for one fiscal year quarter, which can be used by researchers to examine trends in pet ownership among shelter entrants and inform policy or resource planning.
A tibble containing Local Law 97 of 2021 - Pets in Shelter Report data.
NYC Open Data: <https://data.cityofnewyork.us/Social-Services/Local-Law-97-of-2021-Pets-in-Shelter-Report/5nux-zfmw/about_data>
# Examples that hit the live NYC Open Data API are guarded so CRAN checks
# do not fail when the network is unavailable or slow.
if (interactive() && curl::has_internet()) {
# Quick example (fetch 2 rows)
small_sample <- nyc_locallaw97_shelter_pets(limit = 2)
small_sample
nyc_locallaw97_shelter_pets(limit = 2, filters = list(date_quarter = "Qtr 1"))
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.