Learn R Programming

nycOpenData (version 0.1.5)

nyc_school_discharge_report_2015_2018: 2015-2018 School Closure Discharge Reporting

Description

Downloads 2015-2018 School Closure Discharge Reporting data from NYC Open Data.

Usage

nyc_school_discharge_report_2015_2018(limit = 10000, filters = list())

Value

A tibble containing School Closure Discharge Report data.

Arguments

limit

Number of rows to retrieve (default = 10,000).

filters

Optional list of field-value pairs to filter results.

Details

This dataset provides data regarding students enrolled in the closed schools according to the guidelines set by Local Law 43 of 2011.

Examples

Run this code
# Quick example (fetch 2 rows)
small_sample <- nyc_school_discharge_report_2015_2018(limit = 2)
small_sample

# \donttest{
nyc_school_discharge_report_2015_2018(filters = list(geography = "Borough"))
# }

Run the code above in your browser using DataLab