Learn R Programming

nycOpenData (version 0.1.6)

nyc_shooting_incidents: NYPD Shootings

Description

Downloads NYPD Shooting Incident data from NYC Open Data.

Usage

nyc_shooting_incidents(limit = 10000, filters = list(), timeout_sec = 30)

Value

A tibble containing NYPD Shooting Incident Data (Year to Date) data.

Arguments

limit

Number of rows to retrieve (default = 10,000).

filters

Optional list of field-value pairs to filter results.

timeout_sec

Request timeout in seconds (default = 30).

Details

This is a dataset identifies of every shooting incident that occurred in NYC since 2006.

Examples

Run this code
# Examples that hit the live NYC Open Data API are guarded so CRAN checks
# do not fail when the network is unavailable or slow.
if (interactive() && curl::has_internet()) {
  # Quick example (fetch 2 rows)
  small_sample <- nyc_shooting_incidents(limit = 2)
  small_sample

  nyc_shooting_incidents(limit = 2, filters = list(boro = "BROOKLYN"))
}

Run the code above in your browser using DataLab