Learn R Programming

nycOpenData (version 0.1.6)

nyc_wetlands: NYC Wetlands

Description

Downloads NYC Wetlands data from NYC Open Data.

Usage

nyc_wetlands(limit = 10000, filters = list(), timeout_sec = 30)

Value

A tibble containing NYC Wetlands data.

Arguments

limit

Number of rows to retrieve (default = 10,000).

filters

Optional list of field-value pairs to filter results.

timeout_sec

Request timeout in seconds (default = 30).

Details

This dataset includes verified and unverified wetland features that exist in New York City and their respective locations. The columns include the wetland class of each feature, the year it was verified (if applicable), and the feature's location, size, and shape using geospatial tools. This dataset would be particularly useful for researchers looking to visualize NYC's wetlands on a map, or to count the total number of features in each wetland class.

Examples

Run this code
# Examples that hit the live NYC Open Data API are guarded so CRAN checks
# do not fail when the network is unavailable or slow.
if (interactive() && curl::has_internet()) {
  # Quick example (fetch 2 rows)
  small_sample <- nyc_wetlands(limit = 2)
  small_sample

  nyc_wetlands(limit = 2, filters = list(classname = "Forested"))
}

Run the code above in your browser using DataLab